@@ -18,7 +18,7 @@ var searchData=
   ['getfrequencyrange_15',['getFrequencyRange',['../classSoapySDR_1_1Device.html#a20db73ac4454b9e0c4cb256b422c85ff',1,'SoapySDR::Device::getFrequencyRange(const int direction, const size_t channel) const'],['../classSoapySDR_1_1Device.html#aeda805edf2268a9ab853c62b5cee8a6f',1,'SoapySDR::Device::getFrequencyRange(const int direction, const size_t channel, const std::string &amp;name) const']]],
   ['getfrontendmapping_16',['getFrontendMapping',['../classSoapySDR_1_1Device.html#a2356e33672968de0d0a8681badc44aea',1,'SoapySDR::Device']]],
   ['getfullduplex_17',['getFullDuplex',['../classSoapySDR_1_1Device.html#aa4b119a8d481c8e30ac64438ed78773b',1,'SoapySDR::Device']]],
-  ['getfunction_18',['getFunction',['../classSoapySDR_1_1ConverterRegistry.html#a20e9d6ddab1e18044986ad3557550d38',1,'SoapySDR::ConverterRegistry::getFunction(const std::string &amp;sourceFormat, const std::string &amp;targetFormat, const FunctionPriority &amp;priority)'],['../classSoapySDR_1_1ConverterRegistry.html#af741564d5d4c8aa44c55744802e4bc1f',1,'SoapySDR::ConverterRegistry::getFunction(const std::string &amp;sourceFormat, const std::string &amp;targetFormat)']]],
+  ['getfunction_18',['getFunction',['../classSoapySDR_1_1ConverterRegistry.html#af741564d5d4c8aa44c55744802e4bc1f',1,'SoapySDR::ConverterRegistry::getFunction(const std::string &amp;sourceFormat, const std::string &amp;targetFormat)'],['../classSoapySDR_1_1ConverterRegistry.html#a20e9d6ddab1e18044986ad3557550d38',1,'SoapySDR::ConverterRegistry::getFunction(const std::string &amp;sourceFormat, const std::string &amp;targetFormat, const FunctionPriority &amp;priority)']]],
   ['getgain_19',['getGain',['../classSoapySDR_1_1Device.html#aeda40de3260e0d2533e124cbc8a30555',1,'SoapySDR::Device::getGain(const int direction, const size_t channel) const'],['../classSoapySDR_1_1Device.html#aebf2b39abffff300ea542c1c451108e0',1,'SoapySDR::Device::getGain(const int direction, const size_t channel, const std::string &amp;name) const']]],
   ['getgainmode_20',['getGainMode',['../classSoapySDR_1_1Device.html#ad611366d726231b0dc28d0056067f531',1,'SoapySDR::Device']]],
   ['getgainrange_21',['getGainRange',['../classSoapySDR_1_1Device.html#a1582af4ace084477750a18c988ca9e9d',1,'SoapySDR::Device::getGainRange(const int direction, const size_t channel) const'],['../classSoapySDR_1_1Device.html#a30b7b2bde428f35754988135fd94ac05',1,'SoapySDR::Device::getGainRange(const int direction, const size_t channel, const std::string &amp;name) const']]],
@@ -41,8 +41,8 @@ var searchData=
   ['getrootpath_38',['getRootPath',['../namespaceSoapySDR.html#a37a1da663087d48150012087b442c954',1,'SoapySDR']]],
   ['getsamplerate_39',['getSampleRate',['../classSoapySDR_1_1Device.html#a9f514aaebb09ededf52501157bd002fc',1,'SoapySDR::Device']]],
   ['getsampleraterange_40',['getSampleRateRange',['../classSoapySDR_1_1Device.html#a55a126c580dc309727f86a846c77b908',1,'SoapySDR::Device']]],
-  ['getsensorinfo_41',['getSensorInfo',['../classSoapySDR_1_1Device.html#a1633703a9bff94ee296d7c619ed0104f',1,'SoapySDR::Device::getSensorInfo(const int direction, const size_t channel, const std::string &amp;key) const'],['../classSoapySDR_1_1Device.html#ab712a73b723668ae8ffbe2c2377e6049',1,'SoapySDR::Device::getSensorInfo(const std::string &amp;key) const']]],
-  ['getsettinginfo_42',['getSettingInfo',['../classSoapySDR_1_1Device.html#a8a1957452cf3b324061d4a741d98d100',1,'SoapySDR::Device::getSettingInfo(const int direction, const size_t channel) const'],['../classSoapySDR_1_1Device.html#aece5f6bbe0170f785ca6171a4a120e62',1,'SoapySDR::Device::getSettingInfo(void) const']]],
+  ['getsensorinfo_41',['getSensorInfo',['../classSoapySDR_1_1Device.html#ab712a73b723668ae8ffbe2c2377e6049',1,'SoapySDR::Device::getSensorInfo(const std::string &amp;key) const'],['../classSoapySDR_1_1Device.html#a1633703a9bff94ee296d7c619ed0104f',1,'SoapySDR::Device::getSensorInfo(const int direction, const size_t channel, const std::string &amp;key) const']]],
+  ['getsettinginfo_42',['getSettingInfo',['../classSoapySDR_1_1Device.html#aece5f6bbe0170f785ca6171a4a120e62',1,'SoapySDR::Device::getSettingInfo(void) const'],['../classSoapySDR_1_1Device.html#a8a1957452cf3b324061d4a741d98d100',1,'SoapySDR::Device::getSettingInfo(const int direction, const size_t channel) const']]],
   ['getstreamargsinfo_43',['getStreamArgsInfo',['../classSoapySDR_1_1Device.html#a8583ef0bb642a552563a71122fdb5e4c',1,'SoapySDR::Device']]],
   ['getstreamformats_44',['getStreamFormats',['../classSoapySDR_1_1Device.html#a0014bcbd462ea5888fc9625374024823',1,'SoapySDR::Device']]],
   ['getstreammtu_45',['getStreamMTU',['../classSoapySDR_1_1Device.html#ae4ab4e1261a17d635e4551d0e6282868',1,'SoapySDR::Device']]],
